# arranjo_combinacao

Description:
	The arranjo_combinacao package has the arrangement and combination modules.
	Each module provides a function to perform simple arrangement and combination
	of mathematical counting .


## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install arranjo_combinacao.

```bash
pip install arranjo_combinacao
```

## Usage

```python
from arranjo_combinacao import arranjo

arranjo.calcular_arranjo()
```

## Author
Daniel Paes

## License
[MIT](https://choosealicense.com/licenses/mit/)
